@@ -135,9 +135,7 @@ class CohereTextEmbeddingModel(Wrapper):
     ) -> None:
         self.model_name = model_name
         self.sep = sep
-        self.model_prompts = (
-            self.validate_task_to_prompt_name(model_prompts) if model_prompts else None
-        )
+        self.model_prompts = self.validate_task_to_prompt_name(model_prompts)
 
     def _embed(
         self,
