@@ -25,6 +25,7 @@ from mteb.models import (
     cde_models,
     clip_models,
     codesage_models,
+    codi_models,
     cohere_models,
     cohere_v,
     colbert_models,
@@ -58,6 +59,7 @@ from mteb.models import (
     llm2clip_models,
     llm2vec_models,
     mcinext_models,
+    mdbr_models,
     misc_models,
     moco_models,
     model2vec_models,
@@ -73,6 +75,7 @@ from mteb.models import (
     openclip_models,
     opensearch_neural_sparse_models,
     ops_moa_models,
+    ordalietech_solon_embeddings_mini_beta_1_1,
     piccolo_models,
     promptriever_models,
     qodo_models,
@@ -104,7 +107,7 @@ from mteb.models import (
     voyage_models,
     voyage_v,
     xyz_models,
-    codi_models,
+    youtu_models,
 )
 
 logger = logging.getLogger(__name__)
@@ -148,6 +151,7 @@ model_modules = [
     listconranker,
     llm2clip_models,
     llm2vec_models,
+    mdbr_models,
     misc_models,
     model2vec_models,
     moka_models,
@@ -162,6 +166,7 @@ model_modules = [
     openclip_models,
     opensearch_neural_sparse_models,
     ops_moa_models,
+    ordalietech_solon_embeddings_mini_beta_1_1,
     piccolo_models,
     gme_v_models,
     promptriever_models,
@@ -203,6 +208,7 @@ model_modules = [
     mcinext_models,
     vi_vn_models,
     codi_models,
+    youtu_models,
 ]
 MODEL_REGISTRY = {}
 
