@@ -26,14 +26,16 @@ class MedicalQARetrieval(AbsTaskRetrieval):
         annotations_creators="derived",
         dialect=[],
         sample_creation="found",
-        bibtex_citation="""@ARTICLE{BenAbacha-BMC-2019,
-            author    = {Asma, Ben Abacha and Dina, Demner{-}Fushman},
-            title     = {A Question-Entailment Approach to Question Answering},
-            journal = {{BMC} Bioinform.},
-            volume    = {20},
-            number    = {1},
-            pages     = {511:1--511:23},
-            year      = {2019},
-            url       = {https://bmcbioinformatics.biomedcentral.com/articles/10.1186/s12859-019-3119-4}
-            } """,
+        bibtex_citation=r"""
+@article{BenAbacha-BMC-2019,
+  author = {Asma, Ben Abacha and Dina, Demner{-}Fushman},
+  journal = {{BMC} Bioinform.},
+  number = {1},
+  pages = {511:1--511:23},
+  title = {A Question-Entailment Approach to Question Answering},
+  url = {https://bmcbioinformatics.biomedcentral.com/articles/10.1186/s12859-019-3119-4},
+  volume = {20},
+  year = {2019},
+}
+""",
     )
