@@ -24,22 +24,18 @@ class NanoArguAnaRetrieval(AbsTaskRetrieval):
         eval_langs=["eng-Latn"],
         main_score="ndcg_at_10",
         date=["2020-01-01", "2020-12-31"],
-        domains=["Medical", "Written"],
+        domains=["Social", "Web", "Written"],
         task_subtypes=["Discourse coherence"],
         license="cc-by-4.0",
-        annotations_creators="expert-annotated",
+        annotations_creators="derived",
         dialect=[],
         sample_creation="found",
         bibtex_citation=r"""
-@inproceedings{boteva2016,
-  author = {Boteva, Vera and Gholipour, Demian and Sokolov, Artem and Riezler, Stefan},
-  city = {Padova},
-  country = {Italy},
-  journal = {Proceedings of the 38th European Conference on Information Retrieval},
-  journal-abbrev = {ECIR},
-  title = {A Full-Text Learning to Rank Dataset for Medical Information Retrieval},
-  url = {http://www.cl.uni-heidelberg.de/~riezler/publications/papers/ECIR2016.pdf},
-  year = {2016},
+@inproceedings{wachsmuth2018retrieval,
+  author = {Wachsmuth, Henning and Syed, Shahbaz and Stein, Benno},
+  booktitle = {ACL},
+  title = {Retrieval of the Best Counterargument without Prior Topic Knowledge},
+  year = {2018},
 }
 """,
         prompt={"query": "Given a claim, find documents that refute the claim"},
