@@ -26,19 +26,21 @@ class QuoraRetrieval(AbsTaskRetrieval):
         eval_langs=["eng-Latn"],
         main_score="ndcg_at_10",
         date=None,
-        domains=None,
-        task_subtypes=None,
-        license=None,
-        annotations_creators=None,
-        dialect=None,
-        sample_creation=None,
-        bibtex_citation="""@misc{quora-question-pairs,
-    author = {DataCanary, hilfialkaff, Lili Jiang, Meg Risdal, Nikhil Dandekar, tomtung},
-    title = {Quora Question Pairs},
-    publisher = {Kaggle},
-    year = {2017},
-    url = {https://kaggle.com/competitions/quora-question-pairs}
-}""",
+        domains=["Written", "Web", "Blog"],
+        task_subtypes=["Question answering"],
+        license="not specified",
+        annotations_creators="human-annotated",
+        dialect=[],
+        sample_creation="found",
+        bibtex_citation=r"""
+@misc{quora-question-pairs,
+  author = {DataCanary, hilfialkaff, Lili Jiang, Meg Risdal, Nikhil Dandekar, tomtung},
+  publisher = {Kaggle},
+  title = {Quora Question Pairs},
+  url = {https://kaggle.com/competitions/quora-question-pairs},
+  year = {2017},
+}
+""",
         prompt={
             "query": "Given a question, retrieve questions that are semantically equivalent to the given question"
         },
@@ -72,11 +74,14 @@ class QuoraRetrievalHardNegatives(AbsTaskRetrieval):
         annotations_creators=None,
         dialect=None,
         sample_creation=None,
-        bibtex_citation="""@misc{quora-question-pairs,
-    author = {DataCanary, hilfialkaff, Lili Jiang, Meg Risdal, Nikhil Dandekar, tomtung},
-    title = {Quora Question Pairs},
-    publisher = {Kaggle},
-    year = {2017},
-    url = {https://kaggle.com/competitions/quora-question-pairs}
-}""",
+        bibtex_citation=r"""
+@misc{quora-question-pairs,
+  author = {DataCanary, hilfialkaff, Lili Jiang, Meg Risdal, Nikhil Dandekar, tomtung},
+  publisher = {Kaggle},
+  title = {Quora Question Pairs},
+  url = {https://kaggle.com/competitions/quora-question-pairs},
+  year = {2017},
+}
+""",
+        adapted_from=["QuoraRetrieval"],
     )
