@@ -22,17 +22,19 @@ class SciFact(AbsTaskRetrieval):
         main_score="ndcg_at_10",
         date=None,
         domains=["Academic", "Medical", "Written"],
-        task_subtypes=None,
-        license=None,
+        task_subtypes=[],
+        license="not specified",
         annotations_creators=None,
         dialect=None,
         sample_creation=None,
-        bibtex_citation="""@inproceedings{specter2020cohan,
-  title={SPECTER: Document-level Representation Learning using Citation-informed Transformers},
-  author={Arman Cohan and Sergey Feldman and Iz Beltagy and Doug Downey and Daniel S. Weld},
-  booktitle={ACL},
-  year={2020}
-}""",
+        bibtex_citation=r"""
+@inproceedings{specter2020cohan,
+  author = {Arman Cohan and Sergey Feldman and Iz Beltagy and Doug Downey and Daniel S. Weld},
+  booktitle = {ACL},
+  title = {SPECTER: Document-level Representation Learning using Citation-informed Transformers},
+  year = {2020},
+}
+""",
         prompt={
             "query": "Given a scientific claim, retrieve documents that support or refute the claim"
         },
